@@ -250,6 +250,51 @@ def describe_file(remote_full_path, req_url, local_full_path=None,
             raise_(Exception, exc)
 
 
+def modify_file(remote_full_path, req_url, modified_file_name, timeout=3, logger=logging):
+    """
+    修改文件名
+    :param remote_full_path: 远程文件存储路径及完整文件名称，全地址
+    :param req_url: 请求URL地址，必传
+    :param modified_file_name: 修改后的文件名
+    :param timeout: 超时时间
+    :param logger: 日志对象
+    :return:
+    """
+    code, err = None, None
+    try:
+        logger = logger if logger else logging
+        if not remote_full_path or not req_url or not modified_file_name:
+            return 128502, code_dict.get("128502")
+        _, old_name = os.path.split(remote_full_path)
+        if old_name == modified_file_name:
+            return 128507, code_dict.get("128507")
+        param = {'filePath': remote_full_path, 'fileName': modified_file_name}
+        resp = requests.post(url=req_url, json=param, verify=False, timeout=timeout)
+        http_code = resp.status_code
+        if http_code == 200:
+            response = resp.content.decode('utf-8')
+            try:
+                body = json.loads(response)
+            except Exception as exc:
+                body = response
+            print(response)
+            code = body.get('code')
+            err = body.get('err', '') if body.get('err', '') else code_dict.get(str(code))
+        else:
+            code = 1
+            err = "请求失败"
+    except requests.ConnectTimeout:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ConnectionError:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ReadTimeout:
+        code, err = 128509, code_dict.get("128509")
+    except Exception as exc:
+        logger.error(traceback.format_exc())
+        raise_(Exception, exc)
+    return code, err
+
+
 def gen_file(file_path, size=1024):
     """
     将文件读取为文件流
